@@ -22,9 +22,9 @@
  */
 
 /*
- *  $Date: 1999/11/17 17:19:51 $
+ *  $Date: 2000/10/28 18:12:07 $
  *  $Author: hafner $
- *  $Revision: 1.8 $
+ *  $Revision: 1.9 $
  *  $State: Exp $
  */
 
@@ -43,6 +43,107 @@
 #define SCROLLBAR_SPACING(w) (GTK_SCROLLED_WINDOW_CLASS (GTK_OBJECT (w)->klass)->scrollbar_spacing)
 #define RANGE_CLASS(widget)  (GTK_RANGE_CLASS(GTK_OBJECT(widget)->klass))
 
+#ifdef CLASS_BACKUP
+static struct _GtkStepClassBackup
+{
+   /*
+    * GtkHScrollbarClass block
+    */
+   /* GtkRangeClass fields */
+   gint hscrollbar__slider_width;
+   gint hscrollbar__stepper_size;
+   gint hscrollbar__stepper_slider_spacing;
+   gint hscrollbar__min_slider_size;
+
+#ifdef NEXT_SCROLLBAR
+   void (* hscrollbar__motion)          (GtkRange *range,
+					 gint      xdelta,
+					 gint      ydelta);
+   gint (* hscrollbar__trough_click)    (GtkRange *range,
+					 gint      x,
+					 gint      y,
+					 gfloat   *jump_perc);
+   void (* hscrollbar__slider_update)   (GtkRange *range);
+
+   /* GtkWidgetClass fields */
+   void (* hscrollbar__realize)         (GtkWidget      *widget);
+   void (* hscrollbar__size_allocate)   (GtkWidget      *widget,
+					 GtkAllocation  *allocation);
+#endif /* NEXT_SCROLLBAR */
+
+   /*
+    * GtkVScrollbarClass block
+    */
+   /* GtkRangeClass fields */
+   gint vscrollbar__slider_width;
+   gint vscrollbar__stepper_size;
+   gint vscrollbar__stepper_slider_spacing;
+   gint vscrollbar__min_slider_size;
+
+#ifdef NEXT_SCROLLBAR
+   void (* vscrollbar__motion)          (GtkRange *range,
+					 gint      xdelta,
+					 gint      ydelta);
+   gint (* vscrollbar__trough_click)    (GtkRange *range,
+					 gint      x,
+					 gint      y,
+					 gfloat   *jump_perc);
+   void (* vscrollbar__slider_update)   (GtkRange *range);
+  
+   /* GtkWidgetClass fields */
+   void (* vscrollbar__realize)         (GtkWidget      *widget);
+   void (* vscrollbar__size_allocate)       (GtkWidget      *widget,
+					     GtkAllocation  *allocation);
+   void (*vscrollbar__parent_set) (GtkWidget      *widget,
+				   GtkWidget      *previous_parent);
+#endif /* NEXT_SCROLLBAR */
+
+   /*
+    * GtkScrolledWindowClass block
+    */
+   /* GtkScrolledWindowClass fields */
+   gint scrolledwindow__scrollbar_spacing;
+   /* GtkWidgetClass field */
+   void (* scrolledwindow__size_allocate)       (GtkWidget      *widget,
+						 GtkAllocation  *allocation);
+
+   /*
+    * GtkButtonClass block
+    */
+   /* GtkWidgetClass fields */
+   gint (* button__expose_event)        (GtkWidget          *widget,
+					 GdkEventExpose     *event);
+   void (* button__draw)            (GtkWidget      *widget,
+				     GdkRectangle   *area);
+   /*
+    * GtkRadioButtonClass block
+    */
+   /* GtkCheckButtonClass fields */
+   guint16 radiobutton__indicator_size;
+
+   /*
+    * GtkCheckButtonClass block
+    */
+   /* GtkCheckButtonClass fields */
+   guint16 checkbutton__indicator_size;
+
+   /*
+    * GtkHPanedClass block
+    */
+   /* GtkWidgetClass fields */
+   void (* hpaned__size_allocate)       (GtkWidget      *widget,
+					 GtkAllocation  *allocation);
+
+   /*
+    * GtkVPanedClass block
+    */
+   /* GtkWidgetClass fields */
+   void (* vpaned__size_allocate)       (GtkWidget      *widget,
+					 GtkAllocation  *allocation);
+  
+} class_backup;
+#endif /* CLASS_BACKUP */      
+
 /* Theme functions to export */
 void
 theme_init (GtkThemeEngine *engine);
@@ -52,16 +153,10 @@ theme_exit (void);
 /* Exported vtable from th_draw */
 extern GtkStyleClass step_class;
 
-void (*old_hpaned_size_allocate) (GtkWidget     *widget,
-				  GtkAllocation *allocation);
-
 static void
 step_hpaned_size_allocate (GtkWidget     *widget,
 			   GtkAllocation *allocation);
 
-void (*old_vpaned_size_allocate) (GtkWidget     *widget,
-				  GtkAllocation *allocation);
-
 static void
 step_vpaned_size_allocate (GtkWidget     *widget,
 			   GtkAllocation *allocation);
@@ -75,8 +170,7 @@ step_button_expose (GtkWidget      *widget,
 static void
 step_button_paint (GtkWidget    *widget,
 		   GdkRectangle *area);
-static void (*old_parent_set) (GtkWidget      *widget,
-			       GtkWidget      *previous_parent);
+
 void
 step_vscrollbar_parent_set (GtkWidget      *widget,
 			    GtkWidget      *previous_parent);
@@ -131,11 +225,6 @@ step_vscrollbar_realize (GtkWidget *widget);
 static void
 step_hscrollbar_realize (GtkWidget *widget);
 
-void (*old_scrolled_window_map) (GtkWidget *widget);
-static void
-step_scrolled_window_map (GtkWidget *widget);
-void (*old_scrolled_window_size_allocate) (GtkWidget     *widget,
-					   GtkAllocation *allocation);
 static void
 step_scrolled_window_size_allocate (GtkWidget     *widget,
 				    GtkAllocation *allocation);
@@ -494,18 +583,35 @@ theme_init (GtkThemeEngine *engine)
 	 = (GtkHScrollbarClass *) gtk_type_class (gtk_hscrollbar_get_type ());
       rangeclass  = (GtkRangeClass *) hscrollbarclass;
       widgetclass = (GtkWidgetClass *) hscrollbarclass;
-      
+
+#ifdef CLASS_BACKUP
+      class_backup.hscrollbar__slider_width
+	 = rangeclass->slider_width;
+      class_backup.hscrollbar__min_slider_size
+	 = rangeclass->min_slider_size;
+      class_backup.hscrollbar__stepper_size
+	 = rangeclass->stepper_size;
+      class_backup.hscrollbar__stepper_slider_spacing
+	 = rangeclass->stepper_slider_spacing;
+#endif /* CLASS_BACKUP */
       rangeclass->slider_width           = SCROLLBAR_WIDTH;
       rangeclass->min_slider_size        = MINSLIDER_WIDTH;
       rangeclass->stepper_size           = SCROLLBAR_WIDTH;
       rangeclass->stepper_slider_spacing = 1;
 
 #ifdef NEXT_SCROLLBAR
-      rangeclass->motion 	 = step_range_hmotion;
-      rangeclass->trough_click   = step_range_htrough_click;
-      rangeclass->slider_update  = step_hscrollbar_slider_update;
-      widgetclass->realize       = step_hscrollbar_realize;
-      widgetclass->size_allocate = step_hscrollbar_size_allocate;
+#ifdef CLASS_BACKUP
+      class_backup.hscrollbar__motion 	     = rangeclass->motion;
+      class_backup.hscrollbar__trough_click  = rangeclass->trough_click;
+      class_backup.hscrollbar__slider_update = rangeclass->slider_update;
+      class_backup.hscrollbar__realize 	     = widgetclass->realize;
+      class_backup.hscrollbar__size_allocate = widgetclass->size_allocate;
+#endif /* CLASS_BACKUP */
+      rangeclass->motion 	 	     = step_range_hmotion;
+      rangeclass->trough_click   	     = step_range_htrough_click;
+      rangeclass->slider_update  	     = step_hscrollbar_slider_update;
+      widgetclass->realize       	     = step_hscrollbar_realize;
+      widgetclass->size_allocate 	     = step_hscrollbar_size_allocate;
 #endif /* NEXT_SCROLLBAR */
       
       vscrollbarclass
@@ -513,19 +619,36 @@ theme_init (GtkThemeEngine *engine)
       rangeclass  = (GtkRangeClass *) vscrollbarclass;
       widgetclass = (GtkWidgetClass *) vscrollbarclass;
       
+#ifdef CLASS_BACKUP
+      class_backup.vscrollbar__slider_width
+	 = rangeclass->slider_width;
+      class_backup.vscrollbar__min_slider_size
+	 = rangeclass->min_slider_size;
+      class_backup.vscrollbar__stepper_size
+	 = rangeclass->stepper_size;
+      class_backup.vscrollbar__stepper_slider_spacing
+	 = rangeclass->stepper_slider_spacing;
+#endif /* CLASS_BACKUP */
       rangeclass->slider_width           = SCROLLBAR_WIDTH;
       rangeclass->min_slider_size        = MINSLIDER_WIDTH;
       rangeclass->stepper_size           = SCROLLBAR_WIDTH;
       rangeclass->stepper_slider_spacing = 1;
 
 #ifdef NEXT_SCROLLBAR
-      rangeclass->motion 	 = step_range_vmotion;
-      rangeclass->trough_click   = step_range_vtrough_click;
-      rangeclass->slider_update  = step_vscrollbar_slider_update;
-      widgetclass->realize       = step_vscrollbar_realize;
-      widgetclass->size_allocate = step_vscrollbar_size_allocate;
-      old_parent_set             = widgetclass->parent_set;
-      widgetclass->parent_set    = step_vscrollbar_parent_set;
+#ifdef CLASS_BACKUP
+      class_backup.vscrollbar__motion 	     = rangeclass->motion;
+      class_backup.vscrollbar__trough_click  = rangeclass->trough_click;
+      class_backup.vscrollbar__slider_update = rangeclass->slider_update;
+      class_backup.vscrollbar__realize 	     = widgetclass->realize;
+      class_backup.vscrollbar__size_allocate = widgetclass->size_allocate;
+      class_backup.vscrollbar__parent_set    = widgetclass->parent_set;
+#endif /* CLASS_BACKUP */
+      rangeclass->motion 	 	     = step_range_vmotion;
+      rangeclass->trough_click   	     = step_range_vtrough_click;
+      rangeclass->slider_update  	     = step_vscrollbar_slider_update;
+      widgetclass->realize       	     = step_vscrollbar_realize;
+      widgetclass->size_allocate 	     = step_vscrollbar_size_allocate;
+      widgetclass->parent_set    	     = step_vscrollbar_parent_set;
 #endif /* NEXT_SCROLLBAR */
    }
    
@@ -539,9 +662,14 @@ theme_init (GtkThemeEngine *engine)
       scrolled = (GtkScrolledWindowClass *) gtk_type_class (gtk_scrolled_window_get_type ());
       widget_class = (GtkWidgetClass *) scrolled;
       
-      scrolled->scrollbar_spacing 	= 1;
-      old_scrolled_window_size_allocate = widget_class->size_allocate;
-      widget_class->size_allocate 	= step_scrolled_window_size_allocate;
+#ifdef CLASS_BACKUP
+      class_backup.scrolledwindow__scrollbar_spacing
+	 = scrolled->scrollbar_spacing;
+      class_backup.scrolledwindow__size_allocate
+	 = widget_class->size_allocate;
+#endif /* CLASS_BACKUP */
+      scrolled->scrollbar_spacing = 1;
+      widget_class->size_allocate = step_scrolled_window_size_allocate;
    }
 
    /*
@@ -551,11 +679,16 @@ theme_init (GtkThemeEngine *engine)
       GtkButtonClass *buttonclass;
       GtkWidgetClass *widget_class;
 
-      buttonclass  = (GtkButtonClass *) gtk_type_class (gtk_button_get_type ());
+      buttonclass
+	 = (GtkButtonClass *) gtk_type_class (gtk_button_get_type ());
       widget_class = (GtkWidgetClass *) buttonclass;
 
-      widget_class->expose_event = step_button_expose;
-      widget_class->draw 	 = step_button_draw;
+#ifdef CLASS_BACKUP
+      class_backup.button__expose_event = widget_class->expose_event;
+      class_backup.button__draw 	= widget_class->draw;
+#endif /* CLASS_BACKUP */
+      widget_class->expose_event 	= step_button_expose;
+      widget_class->draw 	 	= step_button_draw;
    }
    
    /*
@@ -565,13 +698,19 @@ theme_init (GtkThemeEngine *engine)
       GtkRadioButtonClass *radiobuttonclass;
       GtkCheckButtonClass *checkbuttonclass;
 
-      radiobuttonclass
-	 = (GtkRadioButtonClass *) gtk_type_class (gtk_radio_button_get_type ());
+      radiobuttonclass = (GtkRadioButtonClass *) gtk_type_class (gtk_radio_button_get_type ());
       checkbuttonclass = (GtkCheckButtonClass *) radiobuttonclass;
+#ifdef CLASS_BACKUP
+      class_backup.radiobutton__indicator_size
+	 = checkbuttonclass->indicator_size;
+#endif /* CLASS_BACKUP */
       checkbuttonclass->indicator_size = INDICATOR_SIZE;
 
-      checkbuttonclass
-	 = (GtkCheckButtonClass *) gtk_type_class (gtk_check_button_get_type ());
+      checkbuttonclass = (GtkCheckButtonClass *) gtk_type_class (gtk_check_button_get_type ());
+#ifdef CLASS_BACKUP
+      class_backup.checkbutton__indicator_size
+	 = checkbuttonclass->indicator_size;
+#endif /* CLASS_BACKUP */
       checkbuttonclass->indicator_size = INDICATOR_SIZE;
    }
 
@@ -587,18 +726,145 @@ theme_init (GtkThemeEngine *engine)
       hpanedclass = (GtkHPanedClass *) gtk_type_class (gtk_hpaned_get_type ());
       vpanedclass = (GtkVPanedClass *) gtk_type_class (gtk_vpaned_get_type ());
 
-      h_widget_class 		    = (GtkWidgetClass *) hpanedclass;
-      v_widget_class 		    = (GtkWidgetClass *) vpanedclass;
-      old_hpaned_size_allocate 	    = h_widget_class->size_allocate;
-      old_vpaned_size_allocate 	    = v_widget_class->size_allocate;
-      h_widget_class->size_allocate = step_hpaned_size_allocate;
-      v_widget_class->size_allocate = step_vpaned_size_allocate;
+      h_widget_class 		    	 = (GtkWidgetClass *) hpanedclass;
+      v_widget_class 		    	 = (GtkWidgetClass *) vpanedclass;
+#ifdef CLASS_BACKUP
+      class_backup.hpaned__size_allocate = h_widget_class->size_allocate;
+      class_backup.vpaned__size_allocate = v_widget_class->size_allocate;
+#endif /* CLASS_BACKUP */
+      h_widget_class->size_allocate 	 = step_hpaned_size_allocate;
+      v_widget_class->size_allocate 	 = step_vpaned_size_allocate;
    }
 }
 
 void
 theme_exit (void)
 {
+   /*
+    *  Restore all class property which modified by gtkstep.
+    */
+   {
+      GtkRangeClass	 *rangeclass;
+      GtkHScrollbarClass *hscrollbarclass;
+      GtkVScrollbarClass *vscrollbarclass;
+      GtkWidgetClass     *widgetclass;
+
+      hscrollbarclass
+	 = (GtkHScrollbarClass *) gtk_type_class (gtk_hscrollbar_get_type ());
+      rangeclass  = (GtkRangeClass *) hscrollbarclass;
+      widgetclass = (GtkWidgetClass *) hscrollbarclass;
+      
+#ifdef CLASS_BACKUP
+      rangeclass->slider_width
+	 = class_backup.hscrollbar__slider_width;
+      rangeclass->min_slider_size
+	 = class_backup.hscrollbar__min_slider_size;
+      rangeclass->stepper_size
+	 = class_backup.hscrollbar__stepper_size;
+      rangeclass->stepper_slider_spacing
+	 = class_backup.hscrollbar__stepper_slider_spacing;
+#endif /* CLASS_BACKUP */
+
+#ifdef NEXT_SCROLLBAR
+#ifdef CLASS_BACKUP
+      rangeclass->motion 	 = class_backup.hscrollbar__motion;
+      rangeclass->trough_click   = class_backup.hscrollbar__trough_click;
+      rangeclass->slider_update  = class_backup.hscrollbar__slider_update;
+      widgetclass->realize       = class_backup.hscrollbar__realize;
+      widgetclass->size_allocate = class_backup.hscrollbar__size_allocate;
+#endif /* CLASS_BACKUP */
+#endif /* NEXT_SCROLLBAR */
+      
+      vscrollbarclass
+	 = (GtkVScrollbarClass *) gtk_type_class (gtk_vscrollbar_get_type ());
+      rangeclass  = (GtkRangeClass *) vscrollbarclass;
+      widgetclass = (GtkWidgetClass *) vscrollbarclass;
+      
+#ifdef CLASS_BACKUP
+      rangeclass->slider_width
+	 = class_backup.vscrollbar__slider_width;
+      rangeclass->min_slider_size
+	 = class_backup.vscrollbar__min_slider_size;
+      rangeclass->stepper_size
+	 = class_backup.vscrollbar__stepper_size;
+      rangeclass->stepper_slider_spacing
+	 = class_backup.vscrollbar__stepper_slider_spacing;
+#endif /* CLASS_BACKUP */      
+
+#ifdef NEXT_SCROLLBAR
+#ifdef CLASS_BACKUP
+      rangeclass->motion 	 = class_backup.vscrollbar__motion;
+      rangeclass->trough_click   = class_backup.vscrollbar__trough_click;
+      rangeclass->slider_update  = class_backup.vscrollbar__slider_update;
+      widgetclass->realize       = class_backup.vscrollbar__realize;
+      widgetclass->size_allocate = class_backup.vscrollbar__size_allocate;
+      widgetclass->parent_set    = class_backup.vscrollbar__parent_set;
+#endif /* CLASS_BACKUP */      
+#endif /* NEXT_SCROLLBAR */
+   }
+   
+   {
+      GtkScrolledWindowClass *scrolled;
+      GtkWidgetClass	     *widget_class;
+      
+      scrolled = (GtkScrolledWindowClass *) gtk_type_class (gtk_scrolled_window_get_type ());
+      widget_class = (GtkWidgetClass *) scrolled;
+      
+#ifdef CLASS_BACKUP
+      scrolled->scrollbar_spacing
+	 = class_backup.scrolledwindow__scrollbar_spacing;
+      widget_class->size_allocate
+	 = class_backup.scrolledwindow__size_allocate;
+#endif /* CLASS_BACKUP */
+   }
+
+   {
+      GtkButtonClass *buttonclass;
+      GtkWidgetClass *widget_class;
+
+      buttonclass = (GtkButtonClass *) gtk_type_class (gtk_button_get_type ());
+      widget_class = (GtkWidgetClass *) buttonclass;
+
+#ifdef CLASS_BACKUP
+      widget_class->expose_event = class_backup.button__expose_event;
+      widget_class->draw 	 = class_backup.button__draw;
+#endif /* CLASS_BACKUP */
+   }
+   
+   {
+      GtkRadioButtonClass *radiobuttonclass;
+      GtkCheckButtonClass *checkbuttonclass;
+
+      radiobuttonclass = (GtkRadioButtonClass *) gtk_type_class (gtk_radio_button_get_type ());
+      checkbuttonclass = (GtkCheckButtonClass *) radiobuttonclass;
+#ifdef CLASS_BACKUP
+      checkbuttonclass->indicator_size
+	 = class_backup.radiobutton__indicator_size;
+#endif /* CLASS_BACKUP */      
+
+      checkbuttonclass = (GtkCheckButtonClass *) gtk_type_class (gtk_check_button_get_type ());
+#ifdef CLASS_BACKUP
+      checkbuttonclass->indicator_size
+	 = class_backup.checkbutton__indicator_size;
+#endif /* CLASS_BACKUP */      
+   }
+
+   {
+      GtkHPanedClass *hpanedclass;
+      GtkVPanedClass *vpanedclass;
+      GtkWidgetClass *v_widget_class;
+      GtkWidgetClass *h_widget_class;
+       
+      hpanedclass = (GtkHPanedClass *) gtk_type_class (gtk_hpaned_get_type ());
+      vpanedclass = (GtkVPanedClass *) gtk_type_class (gtk_vpaned_get_type ());
+
+      h_widget_class 		    = (GtkWidgetClass *) hpanedclass;
+      v_widget_class 		    = (GtkWidgetClass *) vpanedclass;
+#ifdef CLASS_BACKUP
+      h_widget_class->size_allocate = class_backup.hpaned__size_allocate;
+      v_widget_class->size_allocate = class_backup.vpaned__size_allocate;
+#endif /* CLASS_BACKUP */      
+   }
 }
 
 /*
@@ -630,7 +896,7 @@ step_vpaned_size_allocate (GtkWidget     *widget,
 
    if (paned->gutter_size < 10)
       paned->gutter_size = 10;
-   old_vpaned_size_allocate (widget, allocation);
+   class_backup.vpaned__size_allocate (widget, allocation);
    if (paned->gutter_size < 10)
       paned->gutter_size = 10;
 
@@ -654,7 +920,7 @@ step_hpaned_size_allocate (GtkWidget     *widget,
 
    if (paned->gutter_size < 10)
       paned->gutter_size = 10;
-   old_hpaned_size_allocate (widget, allocation);
+   class_backup.hpaned__size_allocate (widget, allocation);
    if (paned->gutter_size < 10)
       paned->gutter_size = 10;
 
@@ -692,7 +958,9 @@ step_button_draw (GtkWidget    *widget,
 
       step_button_paint (widget, &tmp_area);
 
-      if (GTK_BIN (button)->child && gtk_widget_intersect (GTK_BIN (button)->child, &tmp_area, &child_area))
+      if (GTK_BIN (button)->child
+	  && gtk_widget_intersect (GTK_BIN (button)->child,
+				   &tmp_area, &child_area))
 	gtk_widget_draw (GTK_BIN (button)->child, &child_area);
     }
 }
@@ -742,11 +1010,14 @@ step_button_paint (GtkWidget    *widget,
 	
       x = 0;
       y = 0;
-      width = widget->allocation.width - GTK_CONTAINER (widget)->border_width * 2;
-      height = widget->allocation.height - GTK_CONTAINER (widget)->border_width * 2;
+      width = widget->allocation.width
+	      - GTK_CONTAINER (widget)->border_width * 2;
+      height = widget->allocation.height
+	       - GTK_CONTAINER (widget)->border_width * 2;
 
       gdk_window_set_back_pixmap (widget->window, NULL, TRUE);
-      gdk_window_clear_area (widget->window, area->x, area->y, area->width, area->height);
+      gdk_window_clear_area (widget->window,
+			     area->x, area->y, area->width, area->height);
 
       if (GTK_WIDGET_HAS_DEFAULT (widget) &&
 	  GTK_BUTTON (widget)->relief == GTK_RELIEF_NORMAL)
@@ -816,43 +1087,48 @@ step_hscrollbar_realize (GtkWidget *widget)
   GTK_WIDGET_SET_FLAGS (widget, GTK_REALIZED);
   range = GTK_RANGE (widget);
   
-  attributes.x = widget->allocation.x;
-  attributes.y = widget->allocation.y + (widget->allocation.height - widget->requisition.height) / 2;
-  attributes.width = widget->allocation.width;
-  attributes.height = widget->requisition.height;
-  attributes.wclass = GDK_INPUT_OUTPUT;
-  attributes.window_type = GDK_WINDOW_CHILD;
-  attributes.visual = gtk_widget_get_visual (widget);
-  attributes.colormap = gtk_widget_get_colormap (widget);
-  attributes.event_mask = gtk_widget_get_events (widget);
-  attributes.event_mask |= (GDK_EXPOSURE_MASK |
-                            GDK_BUTTON_PRESS_MASK |
-                            GDK_BUTTON_RELEASE_MASK |
-                            GDK_ENTER_NOTIFY_MASK |
-                            GDK_LEAVE_NOTIFY_MASK);
+  attributes.x 		  = widget->allocation.x;
+  attributes.y 		  = widget->allocation.y
+			    + (widget->allocation.height
+			       - widget->requisition.height) / 2;
+  attributes.width 	  = widget->allocation.width;
+  attributes.height 	  = widget->requisition.height;
+  attributes.wclass 	  = GDK_INPUT_OUTPUT;
+  attributes.window_type  = GDK_WINDOW_CHILD;
+  attributes.visual 	  = gtk_widget_get_visual (widget);
+  attributes.colormap 	  = gtk_widget_get_colormap (widget);
+  attributes.event_mask   = gtk_widget_get_events (widget);
+  attributes.event_mask  |= (GDK_EXPOSURE_MASK |
+			     GDK_BUTTON_PRESS_MASK |
+			     GDK_BUTTON_RELEASE_MASK |
+			     GDK_ENTER_NOTIFY_MASK |
+			     GDK_LEAVE_NOTIFY_MASK);
   
   attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL | GDK_WA_COLORMAP;
-  widget->window = gdk_window_new (gtk_widget_get_parent_window (widget), &attributes, attributes_mask);
+  widget->window  = gdk_window_new (gtk_widget_get_parent_window (widget),
+				    &attributes, attributes_mask);
   
   range->trough = widget->window;
   gdk_window_ref (range->trough);
   
-  attributes.x = widget->style->klass->xthickness;
-  attributes.y = widget->style->klass->ythickness;
-  attributes.width = RANGE_CLASS (widget)->stepper_size;
+  attributes.x 	    = widget->style->klass->xthickness;
+  attributes.y 	    = widget->style->klass->ythickness;
+  attributes.width  = RANGE_CLASS (widget)->stepper_size;
   attributes.height = RANGE_CLASS (widget)->stepper_size;
   
-  range->step_back = gdk_window_new (range->trough, &attributes, attributes_mask);
+  range->step_back = gdk_window_new (range->trough, &attributes,
+				     attributes_mask);
   
   attributes.x = widget->style->klass->xthickness
 		 + RANGE_CLASS (widget)->stepper_size;
   
-  range->step_forw = gdk_window_new (range->trough, &attributes, attributes_mask);
+  range->step_forw = gdk_window_new (range->trough, &attributes,
+				     attributes_mask);
   
-  attributes.x = 0;
-  attributes.y = widget->style->klass->ythickness;
-  attributes.width = RANGE_CLASS (widget)->min_slider_size;
-  attributes.height = RANGE_CLASS (widget)->slider_width;
+  attributes.x 		 = 0;
+  attributes.y 		 = widget->style->klass->ythickness;
+  attributes.width 	 = RANGE_CLASS (widget)->min_slider_size;
+  attributes.height 	 = RANGE_CLASS (widget)->slider_width;
   attributes.event_mask |= (GDK_BUTTON_MOTION_MASK |
                             GDK_POINTER_MOTION_HINT_MASK);
   
@@ -901,46 +1177,51 @@ step_vscrollbar_realize (GtkWidget *widget)
   GTK_WIDGET_SET_FLAGS (widget, GTK_REALIZED);
   range = GTK_RANGE (widget);
   
-  attributes.x = widget->allocation.x + (widget->allocation.width - widget->requisition.width) / 2;
-  attributes.y = widget->allocation.y;
-  attributes.width = widget->requisition.width;
-  attributes.height = widget->allocation.height;
-  attributes.wclass = GDK_INPUT_OUTPUT;
-  attributes.window_type = GDK_WINDOW_CHILD;
-  attributes.visual = gtk_widget_get_visual (widget);
-  attributes.colormap = gtk_widget_get_colormap (widget);
-  attributes.event_mask = gtk_widget_get_events (widget);
-  attributes.event_mask |= (GDK_EXPOSURE_MASK |
-                            GDK_BUTTON_PRESS_MASK |
-                            GDK_BUTTON_RELEASE_MASK |
-                            GDK_ENTER_NOTIFY_MASK |
-                            GDK_LEAVE_NOTIFY_MASK);
+  attributes.x 		  = widget->allocation.x
+			    + (widget->allocation.width
+			       - widget->requisition.width) / 2;
+  attributes.y 		  = widget->allocation.y;
+  attributes.width 	  = widget->requisition.width;
+  attributes.height 	  = widget->allocation.height;
+  attributes.wclass 	  = GDK_INPUT_OUTPUT;
+  attributes.window_type  = GDK_WINDOW_CHILD;
+  attributes.visual 	  = gtk_widget_get_visual (widget);
+  attributes.colormap 	  = gtk_widget_get_colormap (widget);
+  attributes.event_mask   = gtk_widget_get_events (widget);
+  attributes.event_mask  |= (GDK_EXPOSURE_MASK |
+			     GDK_BUTTON_PRESS_MASK |
+			     GDK_BUTTON_RELEASE_MASK |
+			     GDK_ENTER_NOTIFY_MASK |
+			     GDK_LEAVE_NOTIFY_MASK);
   
   attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL | GDK_WA_COLORMAP;
-  widget->window = gdk_window_new (gtk_widget_get_parent_window (widget), &attributes, attributes_mask);
+  widget->window  = gdk_window_new (gtk_widget_get_parent_window (widget),
+				    &attributes, attributes_mask);
   
   range->trough = widget->window;
   gdk_window_ref (range->trough);
   
-  attributes.x = widget->style->klass->xthickness;
-  attributes.y = (widget->allocation.height -
-		  widget->style->klass->ythickness -
-		  2 * RANGE_CLASS (widget)->stepper_size);
-  attributes.width = RANGE_CLASS (widget)->stepper_size;
+  attributes.x 	    = widget->style->klass->xthickness;
+  attributes.y 	    = (widget->allocation.height -
+		       widget->style->klass->ythickness -
+		       2 * RANGE_CLASS (widget)->stepper_size);
+  attributes.width  = RANGE_CLASS (widget)->stepper_size;
   attributes.height = RANGE_CLASS (widget)->stepper_size;
   
-  range->step_back = gdk_window_new (range->trough, &attributes, attributes_mask);
+  range->step_back = gdk_window_new (range->trough, &attributes,
+				     attributes_mask);
   
   attributes.y = (widget->allocation.height -
                   widget->style->klass->ythickness -
                   RANGE_CLASS (widget)->stepper_size);
   
-  range->step_forw = gdk_window_new (range->trough, &attributes, attributes_mask);
+  range->step_forw = gdk_window_new (range->trough, &attributes,
+				     attributes_mask);
   
-  attributes.x = widget->style->klass->ythickness;
-  attributes.y = 0;
-  attributes.width = RANGE_CLASS (widget)->slider_width;
-  attributes.height = RANGE_CLASS (widget)->min_slider_size;
+  attributes.x 		 = widget->style->klass->ythickness;
+  attributes.y 		 = 0;
+  attributes.width 	 = RANGE_CLASS (widget)->slider_width;
+  attributes.height 	 = RANGE_CLASS (widget)->min_slider_size;
   attributes.event_mask |= (GDK_BUTTON_MOTION_MASK |
                             GDK_POINTER_MOTION_HINT_MASK);
   
@@ -993,22 +1274,27 @@ step_hscrollbar_size_allocate (GtkWidget     *widget,
       
       gdk_window_move_resize (range->trough,
                               allocation->x,
-                              allocation->y + (allocation->height - widget->requisition.height) / 2,
+                              allocation->y
+			      + (allocation->height
+				 - widget->requisition.height) / 2,
                               allocation->width, widget->requisition.height);
       gdk_window_move_resize (range->step_back,
 			      widget->style->klass->xthickness,
                               widget->style->klass->ythickness,
                               RANGE_CLASS (widget)->stepper_size,
-                              widget->requisition.height - widget->style->klass->ythickness * 2);
+                              widget->requisition.height
+			      - widget->style->klass->ythickness * 2);
       gdk_window_move_resize (range->step_forw,
                               widget->style->klass->xthickness +
                               RANGE_CLASS (widget)->stepper_size,
                               widget->style->klass->ythickness,
                               RANGE_CLASS (widget)->stepper_size,
-                              widget->requisition.height - widget->style->klass->ythickness * 2);
+                              widget->requisition.height
+			      - widget->style->klass->ythickness * 2);
       gdk_window_resize (range->slider,
                          RANGE_CLASS (widget)->min_slider_size,
-                         widget->requisition.height - widget->style->klass->ythickness * 2);
+                         widget->requisition.height
+			 - widget->style->klass->ythickness * 2);
       
       gtk_range_slider_update (GTK_RANGE (widget));
     }
@@ -1030,7 +1316,9 @@ step_vscrollbar_size_allocate (GtkWidget     *widget,
       range = GTK_RANGE (widget);
       
       gdk_window_move_resize (range->trough,
-                              allocation->x + (allocation->width - widget->requisition.width) / 2,
+                              allocation->x
+			      + (allocation->width
+				 - widget->requisition.width) / 2,
                               allocation->y,
                               widget->requisition.width, allocation->height);
       gdk_window_move_resize (range->step_back,
@@ -1038,16 +1326,20 @@ step_vscrollbar_size_allocate (GtkWidget     *widget,
 			      allocation->height
 			      - widget->style->klass->ythickness -
 			      2 * RANGE_CLASS (widget)->stepper_size,
-                              widget->requisition.width - widget->style->klass->xthickness * 2,
+                              widget->requisition.width
+			      - widget->style->klass->xthickness * 2,
                               RANGE_CLASS (widget)->stepper_size);
       gdk_window_move_resize (range->step_forw,
                               widget->style->klass->xthickness,
-                              allocation->height - widget->style->klass->ythickness -
+                              allocation->height
+			      - widget->style->klass->ythickness -
                               RANGE_CLASS (widget)->stepper_size,
-                              widget->requisition.width - widget->style->klass->xthickness * 2,
+                              widget->requisition.width
+			      - widget->style->klass->xthickness * 2,
                               RANGE_CLASS (widget)->stepper_size);
       gdk_window_resize (range->slider,
-                         widget->requisition.width - widget->style->klass->xthickness * 2,
+                         widget->requisition.width
+			 - widget->style->klass->xthickness * 2,
                          RANGE_CLASS (range)->min_slider_size);
       
       gtk_range_slider_update (GTK_RANGE (widget));
@@ -1092,7 +1384,8 @@ step_range_trough_hdims (GtkRange *range,
 
   tleft = GTK_WIDGET (range)->style->klass->xthickness +
 	  RANGE_CLASS (range)->stepper_slider_spacing;
-  tright = trough_width - slider_length - GTK_WIDGET (range)->style->klass->xthickness;
+  tright = trough_width - slider_length
+	   - GTK_WIDGET (range)->style->klass->xthickness;
 
   if (range->step_back)
     {
@@ -1130,7 +1423,8 @@ step_range_trough_vdims (GtkRange *range,
 
   ttop = GTK_WIDGET (range)->style->klass->ythickness
 	 + RANGE_CLASS (range)->stepper_slider_spacing;
-  tbottom = trough_height - slider_length - GTK_WIDGET (range)->style->klass->ythickness;
+  tbottom = trough_height - slider_length
+	    - GTK_WIDGET (range)->style->klass->ythickness;
 
   if (range->step_back)
     {
@@ -1197,7 +1491,8 @@ step_range_hmotion (GtkRange *range,
     {
       if (range->policy == GTK_UPDATE_CONTINUOUS)
 	{
-	  gtk_signal_emit_by_name (GTK_OBJECT (range->adjustment), "value_changed");
+	  gtk_signal_emit_by_name (GTK_OBJECT (range->adjustment),
+				   "value_changed");
 	}
       else
 	{
@@ -1207,9 +1502,10 @@ step_range_hmotion (GtkRange *range,
 	  if (range->policy == GTK_UPDATE_DELAYED)
 	    {
 	      step_range_remove_timer (range);
-	      range->timer = gtk_timeout_add (SCROLL_DELAY_LENGTH,
-					      (GtkFunction) RANGE_CLASS (range)->timer,
-					      (gpointer) range);
+	      range->timer
+		 = gtk_timeout_add (SCROLL_DELAY_LENGTH,
+				    (GtkFunction) RANGE_CLASS (range)->timer,
+				    (gpointer) range);
 	    }
 	}
     }
@@ -1262,7 +1558,8 @@ step_range_vmotion (GtkRange *range,
     {
       if (range->policy == GTK_UPDATE_CONTINUOUS)
 	{
-	  gtk_signal_emit_by_name (GTK_OBJECT (range->adjustment), "value_changed");
+	  gtk_signal_emit_by_name (GTK_OBJECT (range->adjustment),
+				   "value_changed");
 	}
       else
 	{
@@ -1272,9 +1569,10 @@ step_range_vmotion (GtkRange *range,
 	  if (range->policy == GTK_UPDATE_DELAYED)
 	    {
 	      step_range_remove_timer (range);
-	      range->timer = gtk_timeout_add (SCROLL_DELAY_LENGTH,
-					      (GtkFunction) RANGE_CLASS (range)->timer,
-					      (gpointer) range);
+	      range->timer
+		 = gtk_timeout_add (SCROLL_DELAY_LENGTH,
+				    (GtkFunction) RANGE_CLASS (range)->timer,
+				    (gpointer) range);
 	    }
 	}
     }
@@ -1391,17 +1689,22 @@ step_range_hslider_update (GtkRange *range)
       if (range->adjustment->value < range->adjustment->lower)
 	{
 	  range->adjustment->value = range->adjustment->lower;
-	  gtk_signal_emit_by_name (GTK_OBJECT (range->adjustment), "value_changed");
+	  gtk_signal_emit_by_name (GTK_OBJECT (range->adjustment),
+				   "value_changed");
 	}
       else if (range->adjustment->value > range->adjustment->upper)
 	{
 	  range->adjustment->value = range->adjustment->upper;
-	  gtk_signal_emit_by_name (GTK_OBJECT (range->adjustment), "value_changed");
+	  gtk_signal_emit_by_name (GTK_OBJECT (range->adjustment),
+				   "value_changed");
 	}
 
-      if (range->adjustment->lower != (range->adjustment->upper - range->adjustment->page_size))
-	x += ((right - left) * (range->adjustment->value - range->adjustment->lower) /
-	      (range->adjustment->upper - range->adjustment->lower - range->adjustment->page_size));
+      if (range->adjustment->lower
+	  != (range->adjustment->upper - range->adjustment->page_size))
+	x += ((right - left)
+	      * (range->adjustment->value - range->adjustment->lower)
+	      / (range->adjustment->upper - range->adjustment->lower
+		 - range->adjustment->page_size));
 
       if (x < left)
 	x = left;
@@ -1421,7 +1724,8 @@ step_range_hslider_update (GtkRange *range)
 	 gdk_window_show (range->step_back);
 	 gdk_window_show (range->step_forw);
       }                  
-      gdk_window_move (range->slider, x, GTK_WIDGET (range)->style->klass->ythickness);
+      gdk_window_move (range->slider, x,
+		       GTK_WIDGET (range)->style->klass->ythickness);
     }
 }
 
@@ -1443,17 +1747,22 @@ step_range_vslider_update (GtkRange *range)
       if (range->adjustment->value < range->adjustment->lower)
 	{
 	  range->adjustment->value = range->adjustment->lower;
-	  gtk_signal_emit_by_name (GTK_OBJECT (range->adjustment), "value_changed");
+	  gtk_signal_emit_by_name (GTK_OBJECT (range->adjustment),
+				   "value_changed");
 	}
       else if (range->adjustment->value > range->adjustment->upper)
 	{
 	  range->adjustment->value = range->adjustment->upper;
-	  gtk_signal_emit_by_name (GTK_OBJECT (range->adjustment), "value_changed");
+	  gtk_signal_emit_by_name (GTK_OBJECT (range->adjustment),
+				   "value_changed");
 	}
 
-      if (range->adjustment->lower != (range->adjustment->upper - range->adjustment->page_size))
-	y += ((bottom - top) * (range->adjustment->value - range->adjustment->lower) /
-	      (range->adjustment->upper - range->adjustment->lower - range->adjustment->page_size));
+      if (range->adjustment->lower
+	  != (range->adjustment->upper - range->adjustment->page_size))
+	y += ((bottom - top)
+	      * (range->adjustment->value - range->adjustment->lower)
+	      / (range->adjustment->upper - range->adjustment->lower
+		 - range->adjustment->page_size));
 
       if (y < top)
 	y = top;
@@ -1474,7 +1783,8 @@ step_range_vslider_update (GtkRange *range)
 	 gdk_window_show (range->step_forw);
       }                  
 
-      gdk_window_move (range->slider, GTK_WIDGET (range)->style->klass->xthickness, y);
+      gdk_window_move (range->slider,
+		       GTK_WIDGET (range)->style->klass->xthickness, y);
     }
 }
 
@@ -1516,7 +1826,8 @@ step_hscrollbar_calc_slider_size (GtkHScrollbar *hscrollbar)
         {
           if (range->adjustment->page_size >
               (range->adjustment->upper - range->adjustment->lower))
-            range->adjustment->page_size = range->adjustment->upper - range->adjustment->lower;
+            range->adjustment->page_size = range->adjustment->upper
+					   - range->adjustment->lower;
           
           width = (width * range->adjustment->page_size /
                    (range->adjustment->upper - range->adjustment->lower));
@@ -1569,7 +1880,8 @@ step_vscrollbar_calc_slider_size (GtkVScrollbar *vscrollbar)
         {
           if (range->adjustment->page_size >
               (range->adjustment->upper - range->adjustment->lower))
-            range->adjustment->page_size = range->adjustment->upper - range->adjustment->lower;
+            range->adjustment->page_size = range->adjustment->upper
+					   - range->adjustment->lower;
           
           height = (height * range->adjustment->page_size /
                     (range->adjustment->upper - range->adjustment->lower));
@@ -1592,8 +1904,10 @@ step_vscrollbar_parent_set (GtkWidget      *widget,
    if (widget && widget->parent && GTK_IS_SCROLLED_WINDOW (widget->parent))
       gtk_scrolled_window_set_placement (GTK_SCROLLED_WINDOW (widget->parent),
 					 GTK_CORNER_TOP_RIGHT);
-   if (old_parent_set)
-      old_parent_set (widget, previous_parent);
+#ifdef NEXT_SCROLLBAR
+   if (class_backup.vscrollbar__parent_set)
+      class_backup.vscrollbar__parent_set (widget, previous_parent);
+#endif
 }
 
 static void
@@ -1679,7 +1993,8 @@ step_scrolled_window_size_allocate (GtkWidget     *widget,
       
       do
 	{
-	  step_scrolled_window_relative_allocation (widget, &relative_allocation);
+	  step_scrolled_window_relative_allocation (widget,
+						    &relative_allocation);
 	  
 	  child_allocation.x = relative_allocation.x + allocation->x;
 	  child_allocation.y = relative_allocation.y + allocation->y;
@@ -1738,7 +2053,8 @@ step_scrolled_window_size_allocate (GtkWidget     *widget,
       child_allocation.x += allocation->x;
       child_allocation.y += allocation->y;
 
-      gtk_widget_size_allocate (scrolled_window->hscrollbar, &child_allocation);
+      gtk_widget_size_allocate (scrolled_window->hscrollbar,
+				&child_allocation);
     }
   else if (GTK_WIDGET_VISIBLE (scrolled_window->hscrollbar))
     gtk_widget_hide (scrolled_window->hscrollbar);
@@ -1767,10 +2083,12 @@ step_scrolled_window_size_allocate (GtkWidget     *widget,
       child_allocation.y += allocation->y;
       if (scrolled_window->window_placement == GTK_CORNER_TOP_RIGHT
 	  && scrolled_window->hscrollbar_visible)
-	 child_allocation.height += SCROLLBAR_SPACING (scrolled_window)
-				    + scrolled_window->hscrollbar->requisition.height;
+	 child_allocation.height
+	    += (SCROLLBAR_SPACING (scrolled_window)
+		+ scrolled_window->hscrollbar->requisition.height);
       
-      gtk_widget_size_allocate (scrolled_window->vscrollbar, &child_allocation);
+      gtk_widget_size_allocate (scrolled_window->vscrollbar,
+				&child_allocation);
     }
   else if (GTK_WIDGET_VISIBLE (scrolled_window->vscrollbar))
     gtk_widget_hide (scrolled_window->vscrollbar);
